local AssignSoldier = ...

AssignSoldier:registerEnumValue ("BUILDING_PART_TYPE", "EXTENSION")

AssignSoldier:register({
        DataType = "BUILDING_FUNCTION_TRAINING_GROUND",
        Id = _assignSoldierPrefix .. "_FUNCTION",
        WorkerCapacity = 1,
        RelatedJob = { Job = "STONE_GATE_V6_SOLDIER", Behavior = _assignSoldierPrefix .. "_BEHAVIOR_TREE" },
        TrainingBehaviorList = { _assignSoldierPrefix .. "_BEHAVIOR_TREE" },
        VillagerProfile = "PROFILE_SOLDIER"
})

AssignSoldier:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "STONE_GATE_V6_SOLDIER"
    }
})

AssignSoldier:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "STONE_GATE_V6_SOLDIER"
    }
})

AssignSoldier:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "STONE_GATE_V6_SOLDIER"
    }
})

AssignSoldier:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "STONE_GATE_V6_SOLDIER"
    }
})

-- Register Soldier V6 job
AssignSoldier:register({
	DataType = "JOB",
	Id = "STONE_GATE_V6_SOLDIER",
	JobName = "STONE_GATE_V6_SOLDIER_NAME",
	JobDescription = "STONE_GATE_V6_SOLDIER_DESC",
        CharacterSetup = {
            RightHandObject = { Model = "PREFAB_TOOL_GUARD_PIKE" },
--            WorkAnimation="GUARD",
--            WalkAnimation="GUARD",
            IdleAnimation="GUARD"
        },
	IsLockedByDefault = false,
	UseWorkplaceBehavior = false,
        DefaultBehavior = "BEHAVIOR_SOLDIER",
        ProductionDelay = 30.0,
        AssetJobProgression = "DEFAULT_JOB_PROGRESSION"
})

-- Apply building asset processor
AssignSoldier:registerAssetProcessor("models/arrow.fbx", {
    DataType = "BUILDING_ASSET_PROCESSOR"
})
AssignSoldier:registerAssetProcessor("models/keepTrap.fbx", {
    DataType = "BUILDING_ASSET_PROCESSOR"
})

function registerAEnd(_nameFbxFile, _nameFbx, _nameAsset, _workplaceCustom)
    -- Register Main prefab nodes
    AssignSoldier:registerAssetId("models/" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameFbx .. "Part", _assignSoldierPrefix .. "_" .. _nameAsset .. "_PREFAB")

    -- Register the stone gate set small squared tower root part
    AssignSoldier:register({
	DataType = "BUILDING_PART",
	Id = _assignSoldierPrefix .. "_" .. _nameAsset .. "_PART",
	Name = _assignSoldierPrefix .. "_" .. _nameAsset .. "_NAME",
	Description = _assignSoldierPrefix .. "_" .. _nameAsset .. "_DESC",
	Category = "EXTENSION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _assignSoldierPrefix .. "_" .. _nameAsset .. "_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 0 }
		}
	},
        AssetBuildingFunction = _assignSoldierPrefix .. "_FUNCTION"
    })
    AssignSoldier:registerPrefabComponent("models/" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameFbx .. "Part", {
        DataType = "ASSIGN_SOLDIER_PATH_AEND_COMP",
        Enabled = true,
        WorkplaceCustom = _workplaceCustom
    })
end

registerAEnd("arrow", "Arrow/AEnd", "ARROW", "Arrow")
registerAEnd("keepTrap", "access/keepTrap", "KEEP_TRAP", "KeepTrap")
registerAEnd("keepTrap", "access/keepTrapAccess", "KEEP_TRAP_ACCESS", "KeepTrapAccess")

function registerKeepTrapPlatform(_nameFbx)
    AssignSoldier:registerPrefabComponent("models/keepTrap.fbx/Prefab/access/" .. _nameFbx .. "Part/ladderTilling", {
        DataType = "ASSIGN_SOLDIER_LADDER_TILLING_COMP",
        Enabled = true
    })
    AssignSoldier:registerPrefabComponent("models/keepTrap.fbx/Prefab/access/" .. _nameFbx .. "Part/ladderTilling/ladderTillingUp", {
        DataType = "ASSIGN_SOLDIER_LADDER_TILLING_UP_COMP",
        Enabled = true
    })

    AssignSoldier:registerPrefabComponent("models/keepTrap.fbx/Prefab/access/" .. _nameFbx .. "Part/ladderTilling/ladderTillingBase", {
        DataType = "ASSIGN_SOLDIER_LADDER_TILLING_BASE_COMP",
        Enabled = true
    })

    AssignSoldier:configurePrefabFlagList("models/keepTrap.fbx/Prefab/access/" .. _nameFbx .. "Part", { "PLATFORM" })
    AssignSoldier:configurePrefabFlagList("models/keepTrap.fbx/Prefab/access/" .. _nameFbx .. "Part/ladderTilling", { "PLATFORM" })
end

registerKeepTrapPlatform("keepTrap")
registerKeepTrapPlatform("keepTrapAccess")

function registerPathList(_partName)
    function registerPath(_idx)
        AssignSoldier:registerPrefabComponent("models/" .. _partName .. "/PATH_A_" .. _idx, {
            DataType = "ASSIGN_SOLDIER_PATH_A" .. _idx .. "_COMP",
            Enabled = true
        })
    end
    registerPath("0")
    registerPath("1")
    registerPath("2")
    registerPath("3")
    registerPath("4")
    registerPath("5")
    registerPath("6")
    registerPath("7")
    registerPath("8")
    registerPath("9")
end
registerPathList("arrow.fbx/Prefab/Arrow/AEndPart")
registerPathList("keepTrap.fbx/Prefab/access/keepTrapPart")

AssignSoldier:registerPrefabComponent("models/keepTrap.fbx/Prefab/access/keepTrapAccessPart/KEEP_TRAP_ACCESS_GUARDING_LOCATION", {
            DataType = "ASSIGN_SOLDIER_ACCESS_GUARDING_LOCATION_COMP",
            Enabled = true
})
AssignSoldier:registerPrefabComponent("models/keepTrap.fbx/Prefab/access/keepTrapAccessPart/KEEP_TRAP_ACCESS_INTERMEDIATE_LOCATION_UP", {
            DataType = "ASSIGN_SOLDIER_ACCESS_INTERMEDIATE_LOCATION_UP_COMP",
            Enabled = true
})
AssignSoldier:registerPrefabComponent("models/keepTrap.fbx/Prefab/access/keepTrapAccessPart/KEEP_TRAP_ACCESS_INTERMEDIATE_LOCATION_DOWN", {
            DataType = "ASSIGN_SOLDIER_ACCESS_INTERMEDIATE_LOCATION_DOWN_COMP",
            Enabled = true
})

function registerAx(_nameFbx, _nameAsset)
    -- Register Main prefab nodes
    AssignSoldier:registerAssetId("models/arrow.fbx/Prefab/Arrow/" .. _nameFbx .. "Part", _assignSoldierPrefix .. "_" .. _nameAsset .. "_PREFAB")

    -- Register the stone gate set small squared tower root part
    AssignSoldier:register({
	DataType = "BUILDING_PART",
	Id = _assignSoldierPrefix .. "_" .. _nameAsset .. "_PART",
	Name = _assignSoldierPrefix .. "_" .. _nameAsset .. "_NAME",
	Description = _assignSoldierPrefix .. "_" .. _nameAsset .. "_DESC",
	Category = "EXTENSION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _assignSoldierPrefix .. "_" .. _nameAsset .. "_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 0 }
		}
	}
    })

    AssignSoldier:registerPrefabComponent("models/arrow.fbx/Prefab/Arrow/" .. _nameFbx .. "Part", {
        DataType = "ASSIGN_SOLDIER_PATH_" .. _nameAsset .. "_COMP",
        Enabled = true
    })
end

registerAx("Ax", "AX")
registerAx("ABegin", "ABEGIN")
